==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/Testing/TSFRandomBlockMatrixBuilderImpl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */


#ifndef RANDOMBLOCKMATRIX_BUILDER_IMPL_HPP
#define RANDOMBLOCKMATRIX_BUILDER_IMPL_HPP

#include "TSFRandomBlockMatrixBuilderDecl.hpp"
#include "TSFSimpleBlockOpDecl.hpp"
#include "TSFRandomSparseMatrixBuilderDecl.hpp"



#ifndef HAVE_TEUCHOS_EXPLICIT_INSTANTIATION
#include "TSFSimpleBlockOpImpl.hpp"
#include "TSFRandomSparseMatrixBuilderImpl.hpp"
#endif

using namespace TSFExtended;
using namespace Teuchos;
using std::ostream;

namespace TSFExtended
{

template <class Scalar> 
inline RandomBlockMatrixBuilder<Scalar>
::RandomBlockMatrixBuilder(const VectorSpace<Scalar>& d,
  const VectorSpace<Scalar>& r,
  double blockDensity,
  double onProcDensity,
  double offProcDensity,
  const VectorType<double>& type)
  : OperatorBuilder<double>(d, r, type), op_()
{
  RefCountPtr<SimpleBlockOp<Scalar> > b = 
    rcp(new SimpleBlockOp<Scalar>(this->domain(), this->range()));
  RefCountPtr<LinearOpBase<Scalar, Scalar> > p = b;
  op_ = p;

  for (int i=0; i<this->range().numBlocks(); i++)
  {
    for (int j=0; j<this->domain().numBlocks(); j++)
    {
      RandomSparseMatrixBuilder<Scalar> builder(this->domain().getBlock(j),
        this->range().getBlock(i),
        onProcDensity,
        offProcDensity,
        this->vecType());
      op_.setBlock(i, j, builder.getOp());
    }
  }
  b->endBlockFill();
}
}

#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/Testing/TSFRandomBlockMatrixBuilderImpl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */


#ifndef RANDOMBLOCKMATRIX_BUILDER_IMPL_HPP
#define RANDOMBLOCKMATRIX_BUILDER_IMPL_HPP

#include "TSFRandomBlockMatrixBuilderDecl.hpp"
#include "TSFSimpleBlockOpDecl.hpp"
#include "TSFRandomSparseMatrixBuilderDecl.hpp"



#ifndef HAVE_TEUCHOS_EXPLICIT_INSTANTIATION
#include "TSFSimpleBlockOpImpl.hpp"
#include "TSFRandomSparseMatrixBuilderImpl.hpp"
#endif

using namespace TSFExtended;
using namespace Teuchos;
using std::ostream;

namespace TSFExtended
{

template <class Scalar> 
inline RandomBlockMatrixBuilder<Scalar>
::RandomBlockMatrixBuilder(const VectorSpace<Scalar>& d,
  const VectorSpace<Scalar>& r,
  double blockDensity,
  double onProcDensity,
  double offProcDensity,
  const VectorType<double>& type)
  : OperatorBuilder<double>(d, r, type), op_()
{
  RCP<SimpleBlockOp<Scalar> > b = 
    rcp(new SimpleBlockOp<Scalar>(this->domain(), this->range()));
  RCP<LinearOpBase<Scalar> > p = b;
  op_ = p;

  for (int i=0; i<this->range().numBlocks(); i++)
  {
    for (int j=0; j<this->domain().numBlocks(); j++)
    {
      RandomSparseMatrixBuilder<Scalar> builder(this->domain().getBlock(j),
        this->range().getBlock(i),
        onProcDensity,
        offProcDensity,
        this->vecType());
      op_.setBlock(i, j, builder.getOp());
    }
  }
  b->endBlockFill();
}
}

#endif
